sanitize_profile_name

Function sanitize_profile_name 

pub fn sanitize_profile_name(raw: &str) -> String
Restrict imported profile names to characters that are safe as file names in the profile store (~/.ballistics/profiles/<name>.json).